/**
 * Copyright (c) 2010 Ignasi Barrera
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package org.sjmvc.web.dispatch.path;

/**
 * Regular expression based {@link PathMatcher}.
 * <p>
 * This matcher checks from the beginning of the path to the end of the matching
 * pattern. It does not try to match the full path, in order to be able to map
 * global resources.
 * 
 * @author Ignasi Barrera
 * 
 * @see PathMatcher
 * @see PathBasedRequestDispatcher
 */
public class RegExpPathMatcher implements PathMatcher
{
	/** Prefix used in the matching patter. */
	private static final String PATTERN_PREFIX = "^";

	/** Suffix used in the matching patter. */
	private static final String PATTERN_SUFFIX = ".*$";

	@Override
	public boolean matches(String pattern, String path)
	{
		String matchString = PATTERN_PREFIX + pattern + PATTERN_SUFFIX;
		return path.matches(matchString);
	}

}
