/**
 * Copyright (c) 2010 Ignasi Barrera
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package org.sjmvc.controller;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Mock class to perform {@link Controller} unit tests.
 * 
 * @author Ignasi Barrera
 */
public class MockController extends MethodInvokingController
{

	/**
	 * A method that always succeeds.
	 */
	public void success(HttpServletRequest request, HttpServletResponse response)
	{
		// Do nothing
	}

	/**
	 * A method that always fails.
	 * 
	 * @throws An execution exception.
	 */
	public void fail(HttpServletRequest request, HttpServletResponse response)
	{
		throw new UnsupportedOperationException("MockController execution failure");
	}

	/**
	 * A method that always succeeds.
	 */
	public void invalidArguments()
	{
		// The MethodInvokingController will throw an IllegalArgumentException
	}

	/**
	 * A method that adds an error to the error list.
	 */
	public void addError(HttpServletRequest request, HttpServletResponse response)
	{
		error("Mock error");
	}
}
